# scEvoNet
 scEvoNet can generate [cell state & gene program] network between species or different time points in the same organism using scRNA-seq matrices as an input.
 
## Installation
Install from PyPI <https://pypi.org/project/scevonet>

``pip install scevonet``

You may need to install wheel via ``pip install wheel`` first.

## Usage Principles

